{*******************************************************************************
* Unit      : TSLockPK Demostration program "QLckTst"                          *
*             Uses SLockPK in the "QuickLock" registration mode and the        *
*             SLockPK component in the minimal configuration                   *
*                                                                              *
*             For a more secure application of SLockPK, please see either the  *
*             "LockPK" or the "LockTest" example application, in which more    *
*             secure systems are used. This example program is has the         *
*             minimum configuration, and is intended as a very simple example  *
*             for applications which are free or low cost and high volume.     *
********************************************************************************
* Purpose   : Demonstration/Example program for the SLockPK component          *
*             This program is intended to provide SLockPK users with ideas     *
*             and examples how to use the SLockPK component to achieve         *
*             successful results. You are at liberty to use sections of this   *
*             example code in your applications when you have purchased a      *
*             license for SLockPK                                              *
********************************************************************************
* Copyright : This software  is copyright TSM Inc. 1998-1999                   *
*             This source code may not be distributed to third parties in      *
*             or in part without the written permission of TSM Inc.            *
*             All rights reserved. Liability limited to replacement of         *
*             this original source code in the case of loss or damage because  *
*             the use or misuse of this software.                              *
********************************************************************************
* Version   : 14.05.98  - 1.00  Original Version                               *
*             22.04.99  - 2.00  PK version "SLockPK"                           *
********************************************************************************
* Switches  : None                                                             *
*******************************************************************************}
unit Slockfrm;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, registry, RegFrm, Slock, ExtCtrls, Menus;

type
  TfrmMain = class(TForm)
    btnRegister: TButton;
    grpStatus: TGroupBox;
    lblStatus: TLabel;
    lblStatusDisp: TLabel;
    lblDaysLeft: TLabel;
    lblDaysLeftDisp: TLabel;
    lblStartsLeftDisp: TLabel;
    lblExpiryDateDisp: TLabel;
    lblProtType: TLabel;
    lblProtTypeDisp: TLabel;
    lblStartsLeft: TLabel;
    lblExpiryDate: TLabel;
    lblRegisteredTo: TLabel;
    lblRegisteredToDisp: TLabel;
    bvlStatus: TBevel;
    lblGraceStartsLeft: TLabel;
    lblGraceStartsLeftDisp: TLabel;
    mnuMainMenu: TMainMenu;
    mnmFile: TMenuItem;
    mnpExit: TMenuItem;
    mnmRegister: TMenuItem;
    mnpRegNow: TMenuItem;
    mnmFunction: TMenuItem;
    mnpNormFunc: TMenuItem;
    btnExit: TButton;
    lblVersion: TLabel;
    lblVersionDisp: TLabel;
    Slock1: TSlock;
    mnpRegSep: TMenuItem;
    mnpLoadCertificate: TMenuItem;
    procedure Slock1FirstStart(Sender: TObject);
    procedure Slock1ClockMovedBack(Sender: TObject);
    procedure Slock1Reminder(Sender: TObject);
    procedure Slock1WrongUnlockCode(Sender: TObject);
    procedure Slock1Expired(Sender: TObject);
    procedure btnRegisterClick(Sender: TObject);
    procedure Slock1Register(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure Slock1RegInfoChanged(Sender: TObject);
    procedure Slock1InGracePeriod(Sender: TObject);
    procedure Slock1RegWriteErr(Sender: TObject);
    procedure mnpNormFuncClick(Sender: TObject);
    procedure mnpExitClick(Sender: TObject);
    procedure mnpRegNowClick(Sender: TObject);
    procedure btnExitClick(Sender: TObject);
    procedure Slock1Extend(Sender: TObject);
    procedure Slock1TimedOut(Sender: TObject);
    procedure Slock1RegInfoTamper(Sender: TObject);
    procedure Slock1NoInitCert(Sender: TObject);
    procedure Slock1CertExpired(Sender: TObject);
    procedure Slock1CertAccept(Sender: TObject);
    procedure Slock1CertReject(Sender: TObject);
    procedure Slock1TrialInfoTamper(Sender: TObject);
    procedure Slock1Reset(Sender: TObject);
    procedure Slock1Terminate(Sender: TObject);
    procedure mnpLoadCertificateClick(Sender: TObject);
  private
    procedure UpdateStatus;
  end;

var
  frmMain: TfrmMain;

implementation

{$R *.DFM}

{*******************************************************************************
* Procedure : btnRegisterClick                                                 *
********************************************************************************
* Purpose   : Opens up the window in which the registration information can    *
*             be entered into                                                  *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.btnRegisterClick(Sender: TObject);
var
     frmRegister: TfrmRegister;
begin
     // create the registration window
     frmRegister := TfrmRegister.Create(self);

     // set the caption and show the window
     frmRegister.Caption := 'Register ' + Caption;
     frmRegister.ShowModal;

     // release the window
     frmRegister.Free;

     // Update the status
     UpdateStatus;

end; {btnRegisterClick}

{*******************************************************************************
* Procedure : FormCreate                                                       *
********************************************************************************
* Purpose   : We check the current status of the protection in the form create *
*             of the main form. (Slock1.CheckProtection) The internal state of *
*             Slock is set, and we then use 'UpdateStatus' to read the status  *
*             of Slock out into the status display                             *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.FormCreate(Sender: TObject);
begin
     // Show the version of the Slock component
     lblVersionDisp.Caption := SLock1.GetVersion;

     //load the Certificate public key
     Slock1.LoadPKKey('++11Ik:uYgEAGlrMFX6p1F2by7J2wJ7IFmYODYYxZylGHFH0EovRkt8b' +
                      'NfK39yusGwnHhBTBcaSx9UFmmferhWxTQWsHU');

     // check the protection of the Slock component
     SLock1.CheckProtection;

     // Update the status display and the state of the Buttons/Menupoints
     UpdateStatus;
end; {FormCreate}

{*******************************************************************************
* Procedure : UpdateStatus                                                     *
********************************************************************************
* Purpose   : Loads the internal status of the Slock component into the status *
*             display. Also sets the state of the menus and buttons            *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.UpdateStatus;
begin
     // load the status display
     case Slock1.Status of
     stNotExpired:
          lblStatusDisp.Caption := 'Not Expired';
     stExpired:
          lblStatusDisp.Caption := 'Expired';
     stGrace:
          lblStatusDisp.Caption := 'Grace Period';
     stRegistered:
          lblStatusDisp.Caption := 'Registered';
     end;

     // load the days/starts left display
     case Slock1.ProtectionType of
     ptStartCount:
          begin
               lblProtTypeDisp.Caption := 'Start Count';
               lblDaysLeftDisp.Caption := 'N/A';
               lblStartsLeftDisp.Caption := IntToStr(Slock1.TrialPeriod);
               lblGraceStartsLeftDisp.Caption := IntToStr(Slock1.GracePeriod);
               lblExpiryDateDisp.Caption := 'N/A';
          end;
     ptDayCount:
          begin
               lblProtTypeDisp.Caption := 'Day Count';
               lblDaysLeftDisp.Caption := IntToStr(Slock1.TrialPeriod);
               lblStartsLeftDisp.Caption := 'N/A';
               lblGraceStartsLeftDisp.Caption := IntToStr(Slock1.GracePeriod);
               lblExpiryDateDisp.Caption := DateToStr(Slock1.ExpiryDate);
          end;
     ptExpiryDate:
          begin
               lblProtTypeDisp.Caption := 'Expiry Date';
               lblDaysLeftDisp.Caption := 'N/A';
               lblStartsLeftDisp.Caption := 'N/A';
               lblGraceStartsLeftDisp.Caption := IntToStr(Slock1.GracePeriod);
               lblExpiryDateDisp.Caption := DateToStr(Slock1.ExpiryDate);
          end;
     ptTimed:
          begin
               lblProtTypeDisp.Caption := 'Timed';
               lblDaysLeftDisp.Caption := 'N/A';
               lblStartsLeftDisp.Caption := 'N/A';
               lblGraceStartsLeftDisp.Caption := 'N/A';
               lblExpiryDateDisp.Caption := 'N/A';
          end;
     ptDaysUsed:
          begin
               lblProtTypeDisp.Caption := 'Days Used';
               lblDaysLeftDisp.Caption := 'N/A';
               lblStartsLeftDisp.Caption := IntToStr(Slock1.TrialPeriod);
               lblGraceStartsLeftDisp.Caption := IntToStr(Slock1.GracePeriod);
               lblExpiryDateDisp.Caption := 'N/A';
          end;
     end;

     // load the registration information
     if Slock1.Registered then
     begin
          lblRegisteredToDisp.Caption := Slock1.RegName;
     end
     else
     begin
          lblRegisteredToDisp.Caption := 'N/A';
     end;

     // set the state of the buttons/menus
     mnmFunction.Enabled := (Slock1.Status <> stExpired);
end; {UpdateStatus}

{*******************************************************************************
* Procedure : Slock1Reminder                                                   *
********************************************************************************
* Purpose   : This is the normal reminder event which is triggered when Slock  *
*             has not been registered and has not expired. You can use this as *
*             a reminder that the user should register.                        *
*             The procedure shown here is more complcated than normally,       *
*             because we want to be able to demonstrate all the different forms*
*             of protection.                                                   *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.Slock1Reminder(Sender: TObject);
begin
     if Slock1.ProtectionType = ptStartCount then
          ShowMessage('This is the normal reminder: ' + IntToStr(Slock1.TrialPeriod) +
                      ' starts left in the evaluation period.');
     if Slock1.ProtectionType = ptDayCount then
          ShowMessage('This is the normal reminder: ' + IntToStr(Trunc(Slock1.ExpiryDate - Now)) +
                      ' days left in the evaluation period.');
     if Slock1.ProtectionType = ptExpiryDate then
          ShowMessage('This is the normal reminder: ' + IntToStr(Trunc(Slock1.ExpiryDate - Now)) +
                      ' days left in the evaluation period.');
     if Slock1.ProtectionType = ptDaysUsed then
          ShowMessage('This is the normal reminder: ' + IntToStr(Slock1.TrialPeriod) +
                      ' days left in the evaluation period.');
end; {Slock1Reminder}

{*******************************************************************************
* Procedure : Slock1RegInfoChanged                                             *
********************************************************************************
* Purpose   : This is triggered when the registration information stored in    *
*             Windows registry is checked, and it is found that the name or    *
*             machine has been changed. The input of a new unlock string is    *
*             necessary before the component will be marked as 'registered'    *
*             again.                                                           *
*             For the machine specific registration to be active, the property *
*             'SpecificMachine' must be set to true. Use this with care, as it *
*             can lead to 'false positives' if the user changes the Windows    *
*             registration information.                                        *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.Slock1RegInfoChanged(Sender: TObject);
begin
     ShowMessage('The registration info was changed.');
end; {Slock1RegInfoChanged}

{*******************************************************************************
* Procedure : Slock1InGracePeriod                                              *
********************************************************************************
* Purpose   : This is triggered when the program has expired, but is still in  *
*             the grace period. This gives you the opportunity to display a    *
*             more urgent message to promt the user that his software will soon*
*             expire.                                                          *
*             The procedure shown here is more complcated than normally,       *
*             because we want to be able to demonstrate all the different forms*
*             of protection.                                                   *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.Slock1InGracePeriod(Sender: TObject);
begin
     if Slock1.ProtectionType = ptStartCount then
          ShowMessage('This is the GRACE PERIOD: ' + IntToStr(Slock1.GracePeriod) +
                      ' starts left in the evaluation period.');
     if Slock1.ProtectionType = ptDayCount then
          ShowMessage('This is the GRACE PERIOD: ' + IntToStr(Slock1.GracePeriod)
                       + ' days left in the evaluation period.');
     if Slock1.ProtectionType = ptExpiryDate then
          ShowMessage('This is the GRACE PERIOD: ' + IntToStr(Slock1.GracePeriod)
                       + ' days left in the evaluation period.');
     if Slock1.ProtectionType = ptDaysUsed then
          ShowMessage('This is the GRACE PERIOD: ' + IntToStr(Slock1.GracePeriod) +
                      ' starts left in the evaluation period.');
end; {Slock1InGracePeriod}

{*******************************************************************************
* Procedure : Slock1Register                                                   *
********************************************************************************
* Purpose   : Is called when the OnRegister event in Slock is triggered. In    *
*             this example we just show a short message, but we could also     *
*             use this event to show a thankyou screen, or even enable some    *
*             additional functions.                                            *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.Slock1Register(Sender: TObject);
begin
     ShowMessage('The program has been registered. Thank you for registering!');
     UpdateStatus;
end; {Slock1Register}

{*******************************************************************************
* Procedure : Slock1RegWriteErr                                                *
********************************************************************************
* Purpose   : Is called when the read after write check of the Windows registry*
*             shows that the information was not correctly written.            *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.Slock1RegWriteErr(Sender: TObject);
begin
     ShowMessage('There was an error writing to the registry. The program will terminate.');
     Halt;
end; {Slock1RegWriteErr}

{*******************************************************************************
* Procedure : mnpNormFuncClick                                                 *
********************************************************************************
* Purpose   : This is an example of using Slock to control access to functions *
*             in the 'host' program. The menu point 'Function' is enabled      *
*             or disabled according to the status of Slock.Status.             *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.mnpNormFuncClick(Sender: TObject);
begin
     ShowMessage('This is a normal function - it will be disabled after the program expired.');
end; {mnpNormFuncClick}

{*******************************************************************************
* Procedure : mnpRegNowClick                                                   *
********************************************************************************
* Purpose   : This calls event 'btnRegisterClick' to register Slock            *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.mnpRegNowClick(Sender: TObject);
begin
     btnRegisterClick(self);
end; {mnpRegNowClick}

{*******************************************************************************
* Procedure : Slock1FirstStart                                                 *
********************************************************************************
* Purpose   : This is called the first time that the Slock.CheckProtection     *
*             Method is called (for the current registry key settings). You    *
*             can use this to display a welcome message or Licensing terms and *
*             conditions or even an advert for your other software.            *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.Slock1FirstStart(Sender: TObject);
begin
     ShowMessage('This is the first start! Welcome to the Slock demonstration program by TSM Inc.');
end; {Slock1FirstStart}

{*******************************************************************************
* Procedure : Slock1ClockMovedBack                                             *
********************************************************************************
* Purpose   : People often try to get around a fixed expiry date by setting    *
*             the clock back. This event is triggered when the system clock    *
*             been set back to a date that is before the Slock was even        *
*             created. Normally you would end the program under such a         *
*             a condition.                                                     *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.Slock1ClockMovedBack(Sender: TObject);
begin
     ShowMessage('The clock was moved back!');
end; {Slock1ClockMovedBack}

{*******************************************************************************
* Procedure : Slock1WrongUnlockCode                                            *
********************************************************************************
* Purpose   : This event is triggered when the user enters the wrong unlock    *
*             code. To discourage random attempts at breaking the code with    *
*             brute force, we end the program when the user enters the wrong   *
*             code.                                                            *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.Slock1WrongUnlockCode(Sender: TObject);
begin
     ShowMessage('The unlock code was wrong. Program was not registered and will end.');
     Halt;
end; {Slock1WrongUnlockCode}

{*******************************************************************************
* Procedure : Slock1Expired                                                    *
********************************************************************************
* Purpose   : This event is triggered when the 'CheckProtection' method is     *
*             called and the component has expired (and there is no grace      *
*             period left).                                                    *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.Slock1Expired(Sender: TObject);
begin
     ShowMessage('The program has expired. Some Functions have been disabled. Register to re-enable them.' +
                 'Note: you can have to edit the OnNoInitCert event to update the Certificate so ' +
                 'that this message does not appear.');
end; {Slock1Expired}

{*******************************************************************************
* Procedure : Slock1Extend                                                     *
********************************************************************************
* Purpose   : This event is triggered when the 'RegisterNow' method is called  *
*             with an extension code. The Extension code increments the        *
*             grace period.                                                    *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.Slock1Extend(Sender: TObject);
begin
     ShowMessage('The component has been extended!');
end; {Slock1Extend}

{*******************************************************************************
* Procedure : btnExitClick                                                     *
********************************************************************************
* Purpose   : Closes the program.                                              *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.btnExitClick(Sender: TObject);
begin
     Close;
end; {btnExitClick}

{*******************************************************************************
* Procedure : mnpExitClick                                                     *
********************************************************************************
* Purpose   : Closes the program.                                              *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.mnpExitClick(Sender: TObject);
begin
     Close;
end; {mnpExitClick}

{*******************************************************************************
* Procedure : SLock1TimedOut                                                   *
********************************************************************************
* Purpose   : Is triggered when SLock times out                                *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.Slock1TimedOut(Sender: TObject);
begin
     UpdateStatus;
     ShowMessage('The component has timed out!');
end; {Slock1TimedOut}

{*******************************************************************************
* Procedure : Slock1RegInfoTamper                                              *
********************************************************************************
* Purpose   : This is triggered if the registry has been tampered with (e.g.   *
*             one of the two copies of the registry information has been       *
*             changed or deleted. If this is the case, the user will have to   *
*             enter his Registration code again.                               *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.Slock1RegInfoTamper(Sender: TObject);
begin
     ShowMessage('The registration information has been tampered with.');
end; {Slock1RegInfoTamper}

{*******************************************************************************
* Procedure : TfrmMain.Slock1NoInitCert                                        *
********************************************************************************
* Purpose   : Loads the Trial Profile information the first time the           *
*             application is run. The Certificate passed is a simple Trial     *
*             Certificate and does not use executable checksumming to make the *
*             process as simple as possible.                                   *
*                                                                              *
*             Note - to make the process even more simple, you can even place  *
*             the Certificate at the right location (that defined in the       *
*             "CertRoot", "CertPath" and "CertKey" properties) using the       *
*             the install program (e.g. InstallShield) and we can miss this    *
*             whole part out.                                                  *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.Slock1NoInitCert(Sender: TObject);
var
     TempString: string;
begin
     // load the default certificate
     TempString := '';

     // this Certificate has an expiry date of 31.7.1999
     // you can swap this one out against the one below for testing
     TempString := TempString + '----SLokPK Certificate Begin----';
     TempString := TempString + 'SGz65n9xy+z4fKF8+ECgLuw6+0P7AxMd';
     TempString := TempString + 'mmpgfWOya9duzpcVe87of9zFHzsFrAHh';
     TempString := TempString + 'IMdY3Ff7A+lqFTV4Si6dPYLx6dcouGFA';
     TempString := TempString + 'i81okRsKcHmSX4ZoCe5hCRDqHU1Smxq+';
     TempString := TempString + 'e5nIDHl1zLjcBcO0M1LA23aALjaigG89';
     TempString := TempString + 'tU7J96TDBmNr1G3bYBvwyQWajwoO58mf';
     TempString := TempString + 'PAqZdUlfkA2o1k+fO7MiTjVBIaKuVlaq';
     TempString := TempString + '+3+vn6YRlHzW9Gi2KWLNQYgXQ0fKwhp4';
     TempString := TempString + '-----SLokPK Certificate End-----';

     SLock1.LoadCertString(TempString);
end; {TfrmMain.Slock1NoInitCert}

{*******************************************************************************
* Procedure : Slock1CertExpired                                                *
********************************************************************************
* Purpose   : This event is triggered when the expiry date of the certificate  *
*             is passed.                                                       *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.Slock1CertExpired(Sender: TObject);
begin
     ShowMessage('The certificate has expired - expiry date: ' +
                 FormatDateTime('dd/mm/yyyy', SLock1.CertExpire) + LIT_SEP + LIT_SEP +
                 'Note: Because we are using a hard coded Certificate for simplicity, ' + 
                 'you will have to edit the OnNoInitCert event to update the Certificate so ' +
                 'that this message does not appear any more.');
end; {TfrmMain.Slock1CertExpired}

{*******************************************************************************
* Procedure : Slock1CertAccept                                                 *
********************************************************************************
* Purpose   : This is triggered when a valid certificate is presented to the   *
*             application                                                      *
*             The certificate is then stored in the registry under the CertKey,*
*             CertPath and CertRoot location.                                  *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.Slock1CertAccept(Sender: TObject);
begin
     ShowMessage('The internal configuration has now been performed and the ' +
                 'Trial Certificate has been loaded. ' + LIT_SEP + LIT_SEP + 
                 'You will not see this message again.');
end; {TfrmMain.Slock1CertAccept}

{*******************************************************************************
* Procedure : Slock1CertReject                                                 *
********************************************************************************
* Purpose   : This is triggered when an invalid certificate is presented to the*
*             application                                                      *
*             The certificate is not stored in the registry                    *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.Slock1CertReject(Sender: TObject);
begin
     ShowMessage('The certificate was rejected. Please contact the software author.');
end; {TfrmMain.Slock1CertReject}

{*******************************************************************************
* Procedure : Slock1TrialInfoTamper                                            *
********************************************************************************
* Purpose   : This is triggered if the registry has been tampered with (e.g.   *
*             if the registry information has been changed, deleted or in any  *
*             other way damaged. If this is the case, the user has to enter    *
*             his registration code again.                                     *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.Slock1TrialInfoTamper(Sender: TObject);
begin
     ShowMessage('The registration information has been damaged or tampered with. ' +
                 'You need to re enter the unlock code again.');
end; {TfrmMain.Slock1TrialInfoTamper}

{*******************************************************************************
* Procedure : TfrmMain.Slock1Reset                                             *
********************************************************************************
* Purpose   : This is triggered if a Reset Certificate is received. The Reset  *
*             Certificate sets the intenal state of SLockPK back to what it    *
*             was before the first start.                                      *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.Slock1Reset(Sender: TObject);
begin
     ShowMessage('A Reset Certificate has been received. QLockTest has been reset. ');
end; {TfrmMain.Slock1Reset}

{*******************************************************************************
* Procedure : TfrmMain.Slock1Terminate                                         *
********************************************************************************
* Purpose   : This is triggered if a Terminate Certificate has been received.  *
*             The Terminate Certificate tells the application not to start. As *
*             the Terminate Certificate is stored, this state persists until   *
*             a new valid Certificate is received to overwrite the Terminate   *
*             Certificate. We need to make sure that there is the possibility  *
*             to enter Certificates in this routine, otherwise we can never    *
*             get out of the state again.                                      *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.Slock1Terminate(Sender: TObject);
begin
     ShowMessage('A Terminate Certificate has been received. Place a new ' +
                 'Certificate on the clipboard and press "OK" to try and ' +
                 'remove the Terminate Certificate. If you do not do this, ' +
                 'the application cannot be used');

     // try to load the Certificate
     SLock1.LoadCertClipboard;

     // halt if we do not get a Cert
     Halt;
end; {TfrmMain.Slock1Terminate}

{*******************************************************************************
* Procedure : TfrmMain.mnpLoadCertificateClick                                 *
********************************************************************************
* Purpose   : Allows you to read a Certificate into the example application    *
*             manually. Useful for reading in Reset Certificates.              *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMain.mnpLoadCertificateClick(Sender: TObject);
begin
     ShowMessage('Place the Certificate on the Windows Clipboard and press OK.');
     SLock1.LoadCertClipboard;
end; {TfrmMain.mnpLoadCertificateClick}

end.
